eog r4826 - in branches/gnome-2-24: . src



Author: friemann
Date: Sat Oct 18 12:53:06 2008
New Revision: 4826
URL: http://svn.gnome.org/viewvc/eog?rev=4826&view=rev

Log:
2008-10-18  Felix Riemann  <friemann svn gnome org>

	* src/eog-application.c: (eog_application_open_uri_list):
	Fix two gtk-doc parameter warnings.


Modified:
   branches/gnome-2-24/ChangeLog
   branches/gnome-2-24/src/eog-application.c

Modified: branches/gnome-2-24/src/eog-application.c
==============================================================================
--- branches/gnome-2-24/src/eog-application.c	(original)
+++ branches/gnome-2-24/src/eog-application.c	Sat Oct 18 12:53:06 2008
@@ -155,7 +155,6 @@
 
 /**
  * eog_application_get_instance:
- * @void: 
  *
  * Returns a singleton instance of #EogApplication currently running.
  * If not running yet, it will create one.
@@ -331,7 +330,7 @@
 /**
  * eog_application_open_uri_list:
  * @application: An #EogApplication.
  * @files: A list of URIs.
  * @timestamp: 
  * @flags: 
  * @error: 
@@ -343,7 +342,7 @@
  **/
 gboolean
 eog_application_open_uri_list (EogApplication  *application,
- 			       GSList          *files,
+ 			       GSList          *uri_list,
  			       guint           timestamp,
  			       EogStartupFlags flags,
  			       GError         **error)
@@ -352,7 +351,7 @@
  
  	g_return_val_if_fail (EOG_IS_APPLICATION (application), FALSE);
  
- 	file_list = eog_util_string_list_to_file_list (files);
+ 	file_list = eog_util_string_list_to_file_list (uri_list);
 
  	return eog_application_open_file_list (application,
 					       file_list, 
@@ -331,7 +330,7 @@
  * eog_application_open_uri_list:
  * @application: An #EogApplication.
- * @files: A list of URIs.
+ * @uri_list: A list of URIs.
  * @timestamp: 
  * @flags: 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]